==> cosec-core-1.0.0-sources.jar: me/ahoo/cosec/policy/ActionMatcherFactory.kt <==
/*
 * Copyright [2021-present] [ahoo wang <ahoowang@qq.com> (https://github.com/Ahoo-Wang)].
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *      http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package me.ahoo.cosec.policy

object ActionMatcherFactory {
    fun create(type: String, pattern: String): ActionMatcher {
        return when (type.uppercase()) {
            AllActionMatcher.TYPE -> AllActionMatcher
            NoneActionMatcher.TYPE -> NoneActionMatcher
            PathActionMatcher.TYPE -> if (ActionPatternReplacer.isTemplate(pattern)) {
                ReplaceablePathActionMatcher(
                    pattern
                )
            } else {
                PathActionMatcher(
                    pattern
                )
            }

            RegularActionMatcher.TYPE -> if (ActionPatternReplacer.isTemplate(pattern)) {
                ReplaceableRegularActionMatcher(
                    pattern
                )
            } else {
                RegularActionMatcher(
                    pattern
                )
            }

            else -> throw IllegalArgumentException("Unsupported ActionMatcher type: $type")
        }
    }
}

==> cosec-core-1.0.5-sources.jar: me/ahoo/cosec/policy/ActionMatcherFactory.kt <==
/*
 * Copyright [2021-present] [ahoo wang <ahoowang@qq.com> (https://github.com/Ahoo-Wang)].
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *      http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package me.ahoo.cosec.policy

object ActionMatcherFactory {
    fun create(type: String, pattern: String): ActionMatcher {
        return when (type.lowercase()) {
            AllActionMatcher.TYPE -> AllActionMatcher
            NoneActionMatcher.TYPE -> NoneActionMatcher
            PathActionMatcher.TYPE -> if (ActionPatternReplacer.isTemplate(pattern)) {
                ReplaceablePathActionMatcher(
                    pattern
                )
            } else {
                PathActionMatcher(
                    pattern
                )
            }

            RegularActionMatcher.TYPE -> if (ActionPatternReplacer.isTemplate(pattern)) {
                ReplaceableRegularActionMatcher(
                    pattern
                )
            } else {
                RegularActionMatcher(
                    pattern
                )
            }

            else -> throw IllegalArgumentException("Unsupported ActionMatcher type: $type")
        }
    }
}
